@@ -7,7 +7,7 @@
 
 # Import iris.tests first so that some things can be initialised before
 # importing anything else.
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 from contextlib import contextmanager
 from itertools import repeat
@@ -26,12 +26,49 @@ import numpy.ma as ma
 import iris
 from iris.coords import CellMethod
 from iris.cube import Cube, CubeList
-from iris.fileformats.netcdf import CF_CONVENTIONS_VERSION
-from iris.fileformats.netcdf import Saver
-from iris.fileformats.netcdf import UnknownCellMethodWarning
+from iris.fileformats.netcdf import (
+    CF_CONVENTIONS_VERSION,
+    Saver,
+    UnknownCellMethodWarning,
+)
 import iris.tests.stock as stock
 
 
+@tests.skip_data
+class TestAtmosphereSigma(tests.IrisTest):
+    def setUp(self):
+        # Modify stock cube so it is suitable to have a atmosphere sigma
+        # factory added to it.
+        cube = stock.realistic_4d_no_derived()
+        cube.coord("surface_altitude").rename("surface_air_pressure")
+        cube.coord("surface_air_pressure").units = "Pa"
+        cube.coord("sigma").units = "1"
+        ptop_coord = iris.coords.AuxCoord(1000.0, var_name="ptop", units="Pa")
+        cube.add_aux_coord(ptop_coord, ())
+        cube.remove_coord("level_height")
+        # Construct and add atmosphere sigma factory.
+        factory = iris.aux_factory.AtmosphereSigmaFactory(
+            cube.coord("ptop"),
+            cube.coord("sigma"),
+            cube.coord("surface_air_pressure"),
+        )
+        cube.add_aux_factory(factory)
+        self.cube = cube
+
+    def test_save(self):
+        with self.temp_filename(suffix=".nc") as filename:
+            iris.save(self.cube, filename)
+            self.assertCDL(filename)
+
+    def test_save_load_loop(self):
+        # Ensure that the AtmosphereSigmaFactory is automatically loaded
+        # when loading the file.
+        with self.temp_filename(suffix=".nc") as filename:
+            iris.save(self.cube, filename)
+            cube = iris.load_cube(filename, "air_potential_temperature")
+            assert cube.coords("air_pressure")
+
+
 @tests.skip_data
 class TestHybridPressure(tests.IrisTest):
     def setUp(self):
@@ -298,13 +335,13 @@ class TestCellMeasures(tests.IrisTest):
     def test_print(self):
         cube = iris.load_cube(self.fname)
         printed = cube.__str__()
-        self.assertTrue(
+        self.assertIn(
             (
-                "\n     Cell measures:\n          cell_area"
-                "                           -         -    "
+                "Cell measures:\n"
+                "        cell_area                             -         -    "
                 "    x         x"
-            )
-            in printed
+            ),
+            printed,
         )
 
 
@@ -670,5 +707,21 @@ data:
         self.assertEqual(cs.false_northing, 0.0)
 
 
+class TestConstrainedLoad(tests.IrisTest):
+    filename = tests.get_data_path(
+        ("NetCDF", "label_and_climate", "A1B-99999a-river-sep-2070-2099.nc")
+    )
+
+    def test_netcdf_with_NameConstraint(self):
+        constr = iris.NameConstraint(var_name="cdf_temp_dmax_tmean_abs")
+        cubes = iris.load(self.filename, constr)
+        self.assertEqual(len(cubes), 1)
+        self.assertEqual(cubes[0].var_name, "cdf_temp_dmax_tmean_abs")
+
+    def test_netcdf_with_no_constraint(self):
+        cubes = iris.load(self.filename)
+        self.assertEqual(len(cubes), 3)
+
+
 if __name__ == "__main__":
     tests.main()
